Endpoint topic

Callable endpoints

Each class contains callable methods that will call a method on the server side. These are normally defined in the endpoint directory in your server project. This client sends requests to these endpoints and returns the result.

Example usage:

// How to use GreetingEndpoint.
client.greeting.hello("world!");

// Generic format.
client.<endpoint>.<method>(...);

Please see the full official documentation here

Classes

EndpointAdmin Endpoint
EndpointGreeting Endpoint
This is an example endpoint that returns a greeting message through its hello method.
EndpointMessagingEndpont Endpoint
EndpointSchedule Endpoint
EndpointSubscriptionRequest Endpoint